@@ -1,7 +1,7 @@
 from __future__ import annotations
 
-from pyJJAsim.compute import Matrix
-from pyJJAsim.embedded_graph import EmbeddedGraph, EmbeddedTriangularGraph, EmbeddedHoneycombGraph, EmbeddedSquareGraph
+from compute import Matrix
+from embedded_graph import EmbeddedGraph, EmbeddedTriangularGraph, EmbeddedHoneycombGraph, EmbeddedSquareGraph
 
 import numpy as np
 import scipy
