@@ -8,8 +8,8 @@ import scipy.sparse.linalg
 import scipy.optimize
 from scipy.sparse.linalg import ArpackNoConvergence
 
-from pyJJAsim.compute import Matrix
-from pyJJAsim.josephson_circuit import Circuit
+from compute import Matrix
+from josephson_circuit import Circuit
 
 __all__ = ["CurrentPhaseRelation", "DefaultCPR",
            "StaticProblem", "StaticConfiguration"]
