@@ -5,9 +5,9 @@ import scipy
 import scipy.sparse.linalg
 import scipy.optimize
 
-from pyJJAsim.josephson_circuit import Circuit
-from pyJJAsim.static_problem import DefaultCPR
-from pyJJAsim.static_problem import StaticConfiguration, StaticProblem
+from josephson_circuit import Circuit
+from static_problem import DefaultCPR
+from static_problem import StaticConfiguration, StaticProblem
 
 __all__ = ["TimeEvolutionProblem", "TimeEvolutionResult"]
 
